# stm-metro-client

A python client for the Montreal STM Metro line status.

I created this library to feed data to sensors for STM line status in my HomeAssistant based home automation setup.

Data is provided by the STM through a public xml feed found at http://www2.stm.info/1997/alertesmetro/esm.xml

DISCLAIMER: I am not affiliated to the STM, and bear no responsibility to the data provided by this library/API.

Install using pip:

pip3 install stm-metro-client

